@@ -1,16 +1,7 @@
-/***************************************************************************
-Copyright 2009 Frederik Gladhorn <gladhorn@kde.org>
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
-
+/*
+    SPDX-FileCopyrightText: 2009 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "abstractbackendmode.h"
 #include "prefs.h"
@@ -18,14 +9,13 @@ Copyright 2009 Frederik Gladhorn <gladhorn@kde.org>
 
 using namespace Practice;
 
-AbstractBackendMode::AbstractBackendMode(Practice::AbstractFrontend* frontend, QObject *parent)
+AbstractBackendMode::AbstractBackendMode(Practice::AbstractFrontend *frontend, QObject *parent)
     : QObject(parent)
     , m_frontend(frontend)
-    , m_current(0)
 {
 }
 
-bool AbstractBackendMode::setTestEntry(TestEntry* current)
+bool AbstractBackendMode::setTestEntry(TestEntry *current)
 {
     m_current = current;
     // this default implementation sets up the frontend with the normal word
@@ -37,15 +27,11 @@ bool AbstractBackendMode::setTestEntry(TestEntry* current)
     }
     m_frontend->setSolution(m_current->entry()->translation(m_current->languageTo())->text());
     if (Prefs::practiceSoundEnabled() == true) {
-        m_frontend->setQuestionSound(
-            m_current->entry()-> translation(m_current->languageFrom())->soundUrl());
-        m_frontend->setSolutionSound(
-            m_current->entry()->translation(m_current->languageTo())->soundUrl());
+        m_frontend->setQuestionSound(m_current->entry()->translation(m_current->languageFrom())->soundUrl());
+        m_frontend->setSolutionSound(m_current->entry()->translation(m_current->languageTo())->soundUrl());
     }
-    m_frontend->setQuestionPronunciation(
-        m_current->entry()->translation(m_current->languageFrom())->pronunciation());
-    m_frontend->setSolutionPronunciation(
-        m_current->entry()->translation(m_current->languageTo())->pronunciation());
+    m_frontend->setQuestionPronunciation(m_current->entry()->translation(m_current->languageFrom())->pronunciation());
+    m_frontend->setSolutionPronunciation(m_current->entry()->translation(m_current->languageTo())->pronunciation());
 
     return true;
 }
@@ -62,32 +48,28 @@ grade_t Practice::AbstractBackendMode::currentGradeForEntry() const
 
 void Practice::AbstractBackendMode::updateGrades()
 {
-    KEduVocTranslation* translation = m_current->entry()->translation(m_current->languageTo());
-    //qDebug() << "Update Grades Default Implementation: " << m_frontend->resultState()
+    KEduVocTranslation *translation = m_current->entry()->translation(m_current->languageTo());
+    // qDebug() << "Update Grades Default Implementation: " << m_frontend->resultState()
     //         << " for " << translation->text()
     //         << " grade: " << m_current->entry()->translation(m_current->languageTo())->grade();
 
     translation->incPracticeCount();
     translation->setPracticeDate(QDateTime::currentDateTime());
 
-    updateGrade(*translation, m_frontend->resultState() == AbstractFrontend::AnswerCorrect,
-                m_current->statisticBadCount() == 0);
+    updateGrade(*translation, m_frontend->resultState() == AbstractFrontend::AnswerCorrect, m_current->statisticBadCount() == 0);
 
-    //qDebug() << "new grade: " << m_current->entry()->translation(m_current->languageTo())->grade();
+    // qDebug() << "new grade: " << m_current->entry()->translation(m_current->languageTo())->grade();
 }
 
-
 // ----------------------------------------------------------------
 //                         protected methods
 
-
-void Practice::AbstractBackendMode::updateGrade(KEduVocText &text, bool isCorrectAnswer,
-                                                bool hasNoPreviousBadAnswers)
+void Practice::AbstractBackendMode::updateGrade(KEduVocText &text, bool isCorrectAnswer, bool hasNoPreviousBadAnswers)
 {
     if (isCorrectAnswer) {
         if (hasNoPreviousBadAnswers) {
             if (text.grade() == KV_NORM_GRADE) {
-                if (text.preGrade()  == KV_NORM_GRADE) {
+                if (text.preGrade() == KV_NORM_GRADE) {
                     // If the word was new and correct answer, then
                     // set it to grade, pregrade 2, 0.  This is so
                     // that the user doesn't have to go through all
@@ -95,19 +77,16 @@ void Practice::AbstractBackendMode::updateGrade(KEduVocText &text, bool isCorrec
                     // already knows well.
                     text.setPreGrade(KV_NORM_GRADE);
                     text.setGrade(KV_LEV2_GRADE);
-                }
-                else if (text.preGrade() == KV_MAX_GRADE) {
+                } else if (text.preGrade() == KV_MAX_GRADE) {
                     // If correct answer and last pregrade level, then
                     // set new grade, pregrade to 1, 0.
                     text.setPreGrade(KV_NORM_GRADE);
                     text.setGrade(KV_LEV1_GRADE);
-                }
-                else {
+                } else {
                     // otherwise just increase the pregrade.
                     text.setPreGrade(text.preGrade() + 1); // FIXME: Implement incPreGrade() in the library.
                 }
-            }
-            else {
+            } else {
                 // If grade was > 0 then just increase it.
                 text.incGrade();
             }
@@ -119,5 +98,5 @@ void Practice::AbstractBackendMode::updateGrade(KEduVocText &text, bool isCorrec
         text.incBadCount();
     }
 
-    //qDebug() << "new pregrade, grade: " << text.preGrade() << text.grade();
+    // qDebug() << "new pregrade, grade: " << text.preGrade() << text.grade();
 }
